@@ -61,7 +61,7 @@ class IMAPFolder(BaseFolder):
         # self.copy_ignoreUIDs is used by BaseFolder.
         self.copy_ignoreUIDs = repository.get_copy_ignore_UIDs(
             self.getvisiblename())
-        if self.repository.getidlefolders() > 0:
+        if self.repository.getidlefolders():
             self.idle_mode = True
 
 
@@ -736,12 +736,15 @@ class IMAPFolder(BaseFolder):
                         severity = OfflineImapError.ERROR.MESSAGE
                         raise OfflineImapError(message,
                             OfflineImapError.ERROR.MESSAGE)
+                    self.ui.error("%s. While fetching msg %r in folder %r."
+                        " Query: %s Retrying (%d/%d)"% (
+                            e, uids, self.name, query,
+                            retry_num - fails_left, retry_num
+                            )
+                        )
                     # Release dropped connection, and get a new one.
                     self.imapserver.releaseconnection(imapobj, True)
                     imapobj = self.imapserver.acquireconnection()
-                    self.ui.error("%s. While fetching msg %r in folder %r."
-                        " Retrying (%d/%d)"%
-                        (e, uids, self.name, retry_num - fails_left, retry_num))
         finally:
              # The imapobj here might be different than the one created before
              # the ``try`` clause. So please avoid transforming this to a nice
